@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -41,7 +41,7 @@ namespace metaproxy_1 {
         FactoryFilter();
         ~FactoryFilter();
 
-        bool add_creator(std::string fi, CreateFilterCallback cfc);
+        bool add_creator(const std::string &fi, CreateFilterCallback cfc);
         
         bool drop_creator(std::string fi);
         
