@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -25,15 +25,6 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <sstream>
 
-//#include "config.hpp"
-//#include "filter.hpp"
-
-//#include <boost/thread/mutex.hpp>
-
-
-
-
-
 namespace mp = metaproxy_1;
 namespace yf = mp::filter;
 
@@ -100,6 +91,12 @@ void yf::Bounce::process(mp::Package &package) const
     return;
 }
 
+void mp::filter::Bounce::configure(const xmlNode * ptr, bool test_only,
+                                   const char *path)
+{
+    mp::xml::check_empty(ptr);
+}
+
 static mp::filter::Base* filter_creator()
 {
     return new mp::filter::Bounce;
