@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -35,7 +35,8 @@ namespace metaproxy_1 {
             Impl();
             ~Impl();
             void process(metaproxy_1::Package & package) const;
-            void configure(const xmlNode * ptr);
+            void configure(const xmlNode * ptr, bool test_only,
+                           const char *path);
         private:
             int m_dummy;
         };
@@ -52,9 +53,10 @@ yf::Template::~Template()
 {  // must have a destructor because of boost::scoped_ptr
 }
 
-void yf::Template::configure(const xmlNode *xmlnode, bool test_only)
+void yf::Template::configure(const xmlNode *xmlnode, bool test_only,
+                             const char *path)
 {
-    m_p->configure(xmlnode);
+    m_p->configure(xmlnode, test_only, path);
 }
 
 void yf::Template::process(mp::Package &package) const
@@ -76,7 +78,8 @@ yf::Template::Impl::~Impl()
 { 
 }
 
-void yf::Template::Impl::configure(const xmlNode *xmlnode)
+void yf::Template::Impl::configure(const xmlNode *xmlnode, bool test_only,
+                                   const char *path)
 {
 }
 
